@@ -1,5 +1,5 @@
 package ExtUtils::AutoInstall;
-$ExtUtils::AutoInstall::VERSION = '0.62';
+$ExtUtils::AutoInstall::VERSION = '0.63';
 
 use strict;
 use Cwd ();
@@ -11,8 +11,8 @@ ExtUtils::AutoInstall - Automatic install of dependencies via CPAN
 
 =head1 VERSION
 
-This document describes version 0.62 of B<ExtUtils::AutoInstall>,
-released July 9, 2005.
+This document describes version 0.63 of B<ExtUtils::AutoInstall>,
+released September 12, 2005.
 
 =head1 SYNOPSIS
 
@@ -52,6 +52,13 @@ Invoking the resulting F<Makefile.PL>:
 
 Note that the trailing 'deps' of arguments may be omitted, too.
 
+Using C<--defaultdeps> will make F<Makefile.PL> behave similarly to a regular
+Makefile.PL file with C<PREREQ_PM> dependencies.
+
+One can use environment variables (see "ENVIRONMENT") below to set a default
+behavior instead of specifying it in the command line for every invocation
+of F<Makefile.PL>.
+
 Using F<make> (or F<nmake>):
 
     % make [all|test|install]           # install dependencies first
